
//
// This external variable will let you define how many currency pairs
// could be traded simultaneously.
//

extern int     MaxOpenSymbols = 3;

//
//  Add the MagicNumberBase variables to the EA.
// 
//  Magic numbers should be assigned automatically and the user
//  should only be able to modify the '*MagicNumberBase' numbers
//  if they are in conflict with any other running EAs
//

int      LongMagicNumberBase=110000;
int      ShortMagicNumberBase=210000;


//
// These variables are used for storing the assigned magic numbers.
//

int      LongMagicNumber=0;
int      ShortMagicNumber=0;

//
// Append the following code into your init() function.
//
// This will assign magic numbers automatically.
//

int init()
{
   LongMagicNumber = LongMagicNumberBase + Symbol2Val(Symbol());
   ShortMagicNumber = ShortMagicNumberBase + Symbol2Val(Symbol());
}

//
// These function is used as an aid in assigning magic numbers.
// It assigns a unique integer to a currency pair
//

int Symbol2Val(string symbol)
 {
   string mySymbol = StringSubstr(symbol,0,6);
   
	if(mySymbol=="AUDCAD") return(1);
	if(mySymbol=="AUDJPY") return(2);
	if(mySymbol=="AUDNZD") return(3);
	if(mySymbol=="AUDUSD") return(4);
	if(mySymbol=="CHFJPY") return(5);
	if(mySymbol=="EURAUD") return(6);
	if(mySymbol=="EURCAD") return(7);
	if(mySymbol=="EURCHF") return(8);
	if(mySymbol=="EURGBP") return(9);
	if(mySymbol=="EURJPY") return(10);
	if(mySymbol=="EURUSD") return(11);
	if(mySymbol=="GBPCHF") return(12);
	if(mySymbol=="GBPJPY") return(13);
	if(mySymbol=="GBPUSD") return(14);
	if(mySymbol=="NZDUSD") return(15);
	if(mySymbol=="USDCAD") return(16);
	if(mySymbol=="USDCHF") return(17);
	if(mySymbol=="USDJPY") return(18);
	if(mySymbol=="NZDJPY") return(19);
	return(0);
}

//
// Append the following code into your deinit() function.
//
// This will clear the global variables if the script is removed from the chart.
//

int deinit()
{

   //
   // '*MagicNumber' variables are the magic numbers for a currency pair.
   // I assume that magic numbers are assigned automatically, 
   // so simply substitute '*MagicNumber' for the currently used
   // variable names.
   //

   string GV = DoubleToStr(LongMagicNumber+ShortMagicNumber,0);
   
   GlobalVariableDel(GV);
   return(0);
}  

//
// The 'TradeActive' variable should be set true if the selected currency pair
// is in a trade.
//
// When the trade is over this variable should be reset to false.
//

bool TradeActive = false;

//
// The following variable stores the number of currently traded symbols.
//

int TotalOpenSymbols = 0;

//
// This function should be called in the start() function.
//
// See implementation example in the start() function;
//

int FindOpenSymbols()
{
   int      tos = 0; // total open symbols
   int      os = 19; // maximum number of available curreny pairs (IBFX has 19 so I set it to 19)  

   //
   // '*MagicNumber' variables are the magic numbers for a currency pair.
   // I assume that magic numbers are assigned automatically, 
   // so simply substitute '*MagicNumber' for the currently used
   // variable names.
   //
   
   string   GV  = DoubleToStr(LongMagicNumber+ShortMagicNumber,0);
      
   if(TradeActive == true)
      GlobalVariableSet(GV,1);   
   else
      GlobalVariableSet(GV,0);   
      
   for(os = 1; os < 19; os++)
   {
      if(GlobalVariableCheck(DoubleToStr(LongMagicNumberBase+ShortMagicNumberBase+os,0)))
         tos += GlobalVariableGet(DoubleToStr(LongMagicNumberBase+ShortMagicNumberBase+os,0));
   }
   
   TotalOpenSymbols = tos;
 
   return(TotalOpenSymbols);
}

//
// An implementation example 
//
  
int start()
{
   // .
   // .
   // .

   if(FindOpenSymbols() < MaxOpenSymbols)
   {

      //
      // it is OK to open new trade for this currency pair 
      //

   }

   // .
   // .
   // .

}
  


